@@ -15,9 +15,14 @@ class Extension(ioc.component.Extension):
                     break
 
                 if 'method' not in option:
-                    break                
+                    break
 
                 if 'priority' not in option:
                     option['priority'] = 0
 
-                dispatcher.add_listener(option['name'], getattr(container.get(id), option['method']), option['priority'])
\ No newline at end of file
+                if type(option['method']) == str:
+                    method = getattr(container.get(id), option['method'])
+                else:
+                    method = option['method']
+
+                dispatcher.add_listener(option['name'], method, option['priority'])
\ No newline at end of file
