@@ -1,38 +1,34 @@
+from element.node import NodeHandler
+
 class IndexView(object):
     def __init__(self, container):
         self.container = container
 
-    def execute(self, context):
-        pass
+    def execute(self, request_handler, context):
 
-class ParametersView(object):
+        return 200, 'ioc.extra.stats:index.html', {}
+
+class ParametersView(NodeHandler):
     def __init__(self, container):
         self.container = container
 
-    def execute(self, context, type=None):
-        flask = context.settings['flask']
-        
-        context.node.title = "Parameters"
+    def execute(self, request_handler, context, type=None):
 
         params = {
             'parameters': self.container.parameters,
             'context': context
         }
 
-        return flask.make_response(flask.render_template('ioc.extra.stats:parameters.html', **params))
+        return self.render(request_handler, self.container.get('ioc.extra.jinja2'), 'ioc.extra.stats:parameters.html', params)
 
-class ServicesView(object):
+class ServicesView(NodeHandler):
     def __init__(self, container):
         self.container = container
 
-    def execute(self, context):
-        flask = context.settings['flask']
-
+    def execute(self, request_handler, context):
         context.node.title = "Services"
 
-        params = {
+        return 200, 'ioc.extra.stats:services.html', {
             'services': self.container.services,
             'context': context,
         }
-
-        return flask.make_response(flask.render_template('ioc.extra.stats:services.html', **params))
