@@ -13,16 +13,17 @@ def deepcopy(value):
     We only need to make sure the provided data is a copy per key, object does
     not need to be copied.
     """
+
     if not isinstance(value, (dict, list, tuple)):
         return value
 
     if isinstance(value, dict):
         copy = {}
-        for k, v in value.iteritems():
+        for k, v in value.items():
             copy[k] = deepcopy(v)
 
     if isinstance(value, tuple):
-        copy = range(len(value))
+        copy = list(range(len(value)))
 
         for k in get_keys(list(value)):
             copy[k] = deepcopy(value[k])
@@ -30,7 +31,7 @@ def deepcopy(value):
         copy = tuple(copy)
 
     if isinstance(value, list):
-        copy = range(len(value))
+        copy = list(range(len(value)))
 
         for k in get_keys(value):
             copy[k] = deepcopy(value[k])
@@ -48,7 +49,7 @@ def get_keys(arguments):
         return range(len(arguments))
 
     if isinstance(arguments, (dict)):
-        return arguments.iterkeys()
+        return arguments.keys()
 
     return []
 
@@ -79,14 +80,37 @@ class Dict(object):
     def get_int(self, name, default=None):
         return int(self.get(name, default))
 
+    def get_all(self, name, default=None):
+        return self.get_dict(name, default).all()
+
     def all(self):
-        return self.data
-        
+        def walk(data):
+            all = {}
+
+            if not isinstance(data, dict):
+                return data
+
+            for v, d in data.iteritems():
+                if isinstance(d, Dict):
+                    all[v] = d.all()
+                else:
+                    all[v] = d
+
+                if is_iterable(all[v]):
+                    walk(all[v])
+
+            return all
+
+        return walk(self.data)
+
+    def iteritems(self):
+        return self.data.iteritems()
+
     def __iter__(self):
         return iter(self.data)
 
     def __getitem__(self, key):
-        return self.data[key]     
+        return self.data[key]
 
 def build(files, logger=None, parameters=None):
 
@@ -118,7 +142,7 @@ def build(files, logger=None, parameters=None):
 
     container = ioc.component.Container()
 
-    for name, value in parameters.iteritems():
+    for name, value in parameters.items():
         container_builder.parameters.set(name, value)
 
     container_builder.build_container(container)
