@@ -1,7 +1,7 @@
 # vim: set fileencoding=utf-8 :
 
 import unittest2 as unittest
-import ioc.component, ioc.exceptions, exceptions
+import ioc.component, ioc.exceptions
 import tests.ioc.service
 
 class DefinitionTest(unittest.TestCase):
@@ -142,7 +142,7 @@ class ContainerBuilderTest(unittest.TestCase):
         self.container = ioc.component.ContainerBuilder()
 
     def test_get_class(self):
-        with self.assertRaises(exceptions.AttributeError):
+        with self.assertRaises(AttributeError):
             self.container.get_class(ioc.component.Definition('tests.ioc.test_component.Fake'))
 
         definition = ioc.component.Definition('tests.ioc.service.Fake', [True], {'param': 'salut'})
@@ -171,7 +171,7 @@ class ContainerBuilderTest(unittest.TestCase):
 
         self.container.build_container(container)
 
-        self.assertEquals(4, len(container.services))
+        self.assertEquals(5, len(container.services))
         self.assertTrue(container.has('service.id.2'))
         self.assertIsInstance(container.get('service.id.2'), tests.ioc.service.Fake)
         self.assertIsInstance(container.get('service.id.3'), tests.ioc.service.Foo)
@@ -238,7 +238,7 @@ class ContainerBuilderTest(unittest.TestCase):
 
         self.container.build_container(container)
 
-        self.assertEquals(1, len(container.services))
+        self.assertEquals(2, len(container.services))
 
     def test_create_definition_from_abstract_definition(self):
         self.container.add('service.id.abstract', ioc.component.Definition('tests.ioc.service.Fake', ['foo'], abstract=True))
@@ -248,4 +248,4 @@ class ContainerBuilderTest(unittest.TestCase):
         self.container.add('service.id.1', definition)
 
         container = self.container.build_container(ioc.component.Container())
-        self.assertEquals(2, len(container.services))
+        self.assertEquals(3, len(container.services))
